import packageJson from 'package-json';
import semver from 'semver';
export async function resolveCreateFigmaPluginLatestStableVersions() {
    return {
        build: await resolveLatestStableVersion('@create-figma-plugin/build'),
        tsconfig: await resolveLatestStableVersion('@create-figma-plugin/tsconfig'),
        ui: await resolveLatestStableVersion('@create-figma-plugin/ui'),
        utilities: await resolveLatestStableVersion('@create-figma-plugin/utilities')
    };
}
async function resolveLatestStableVersion(packageName) {
    const result = await packageJson(packageName, { allVersions: true });
    const versions = Object.keys(result.versions).sort(function (a, b) {
        return b.localeCompare(a, [], { numeric: true });
    });
    if (versions.length === 0) {
        throw new Error('No versions');
    }
    for (const version of versions) {
        const parsed = semver.parse(version);
        if (parsed === null) {
            throw new Error(`Invalid version: ${version}`);
        }
        if (parsed.prerelease.length === 0) {
            return version;
        }
    }
    return versions[0];
}
//# sourceMappingURL=resolve-create-figma-plugin-latest-stable-versions.js.map