import { dirname, resolve } from 'node:path';
import { fileURLToPath } from 'node:url';
import { globby } from 'globby';
import inquirer from 'inquirer';
const __dirname = dirname(fileURLToPath(import.meta.url));
export async function resolveTemplateNameAsync(templateName) {
    const templateNames = await readTemplateNamesAsync();
    if (typeof templateName !== 'undefined') {
        if (templateNames.indexOf(templateName) === -1) {
            throw new Error(`Template must be one of "${templateNames.join('", "')}"`);
        }
        return templateName;
    }
    const result = await inquirer.prompt([
        {
            choices: templateNames,
            message: 'Select a template:',
            name: 'templateName',
            type: 'list'
        }
    ]);
    return result.templateName;
}
async function readTemplateNamesAsync() {
    const pluginTemplatesDirectory = resolve(__dirname, '..', '..', 'templates');
    const result = await globby('*/*', {
        cwd: pluginTemplatesDirectory,
        onlyDirectories: true
    });
    return result;
}
//# sourceMappingURL=resolve-template-name-async.js.map